
#
# Makefile.PL
# $Id: 2282029b8f34681732fb87c0e3df09dd269fdb9b $
#
# made by module-starter,  8-Nov-07
#

use strict;
use warnings;
use ExtUtils::MakeMaker;

# BEGIN MODULE LIST
# (flag for update_modules)

# update modularized programs here and in lib/Jdb/Filter/dbpipeline.pm
my @modularized_db_programs = qw(
	dbcol
	dbcolcreate
	dbcoldefine 
	dbcolhisto 
	dbcolmerge 
	dbcolmovingstats
	dbcolneaten
	dbcolpercentile
	dbcolrename
	dbcolscorrelate 
	dbcolsplittocols 
	dbcolsplittorows
	dbcolsregression
	dbcolstats
	dbcolstatscores
	dbfilealter
	dbfilestripcomments 
	dbfilevalidate
	dbformmail 
	dbjoin
	dbmapreduce
	dbmerge
	dbmerge2
	dbmultistats 
	dbrow
	dbrowaccumulate 
	dbrowcount
	dbrowdiff 
	dbroweval
	dbrowuniq 
	dbrvstatdiff
	dbsort
);
my @modularized_db_non_programs = qw(
    dbpipeline
    dbsubprocess
);
my @modularized_db_converters = qw(
    	cgi_to_db
	combined_log_format_to_db
	csv_to_db 
	db_to_csv 
	db_to_html_table 
	html_table_to_db 
	kitrace_to_db 
	mysql_to_db 
	tabdelim_to_db 
	tcpdump_to_db
);
# helper programs: stubs that provide CLI glue around perl modules
my @helper_db_programs = qw(
	dbrowenumerate
);
# backwards programs are bin/db* programs that are just for jdb-1.x compatibility
my @backwards_db_programs = qw(
	dbcolize 
	dblistize 
	dbrecolize 
	dbstats 
	ns_to_db 
);
# discarded programs:
#	dbcoltighten 
#	dbfilesplit 
#	dbstipleadingspace
#	dbstripexraheaders
#	db2dcliff 
#	dbcolmultiscale 
#	dbrowsplituniq 
#
#	crl_to_db 
#	ipchain_logs_to_db 
#	dmalloc_to_db 

# (flag for update_modules)
# END MODULE LIST

my @programs_to_install = (@modularized_db_programs, @modularized_db_converters, @helper_db_programs, @backwards_db_programs);


WriteMakefile(
    NAME                => 'Jdb',
    AUTHOR              => 'John Heidemann <johnh@isi.edu>',
    VERSION_FROM        => 'lib/Jdb.pm',
    ABSTRACT_FROM       => 'lib/Jdb.pm',
    EXE_FILES       => [ map "bin/$_", @programs_to_install ],
    PL_FILES            => {},
    PREREQ_PM => {
        'Test::More' => 0,
        'Text::CSV_XS' => 0,
    },
    dist                => { COMPRESS => 'gzip -9f', SUFFIX => 'gz', },
    clean               => { FILES => 'Jdb-*' },
);

open(MF, ">>Makefile") or die "$0: cannot append to Makefile.\n";

foreach (@modularized_db_programs, @modularized_db_converters) {
    print MF "all :: bin/$_\n\n" .
	"bin/$_: lib/Jdb/Filter/$_.pm ./programize_module\n" .
	"\t./programize_module $_ < \$< > \$\@\n\n";
};

print MF <<'END';

#
# standard option propagation:
# (use in development after editing Filter.pm's common documentation)
#
standardoption:
	echo NOT YET DONE


#
# release stuff:
#

README: lib/Jdb.pm
	pod2text < $<  > $@

README.html: lib/Jdb.pm
	pod2html --noindex < $<  > $@

all :: README README.html

SPEC_PREFIX=Jdb
RPM_ARCH=noarch
RPM_PREFIX=perl-Jdb

Jdb.spec: lib/Jdb.pm
	overwrite $@ sed "s/^Version: .*$$/Version: $(VERSION)/"

rpms: $(SPEC_PREFIX).spec Jdb.spec
	cp $(SPEC_PREFIX)-$(VERSION).tar.gz $$HOME/rpmbuild/SOURCES
	cp $(SPEC_PREFIX).spec $$HOME/rpmbuild/SPECS
	( cd $$HOME/rpmbuild; rpmbuild -ba SPECS/$(SPEC_PREFIX).spec; )
	cp $$HOME/rpmbuild/RPMS/$(RPM_ARCH)/$(RPM_PREFIX)-$(VERSION)-1.$(RPM_ARCH).rpm .
	cp $$HOME/rpmbuild/SRPMS/$(RPM_PREFIX)-$(VERSION)-1.src.rpm .

signrpms: 
	rpm --resign $(RPM_PREFIX)-$(VERSION)*.rpm

WEBDIR=/home/johnh/LIB/WWW/SOFTWARE/JDB

release:
	@echo "You should have done \"make manifest; make dist; make rpms\""
	make signrpms
	cp $(RPM_PREFIX)-$(VERSION)-1.$(RPM_ARCH).rpm $(WEBDIR)
	cp $(RPM_PREFIX)-$(VERSION)-1.src.rpm $(WEBDIR)
	cp $(SPEC_PREFIX)-$(VERSION).tar.gz $(WEBDIR)
	cp README.html $(WEBDIR)/$(SPEC_PREFIX)-$(VERSION)_README.html
	cd $(WEBDIR); git add $(RPM_PREFIX)-$(VERSION)*.rpm $(SPEC_PREFIX)-$(VERSION).tar.gz $(SPEC_PREFIX)-$(VERSION)_README.html
	cd $(WEBDIR); rm Jdb-current.tar.gz; ln -s Jdb-$(VERSION).tar.gz Jdb-current.tar.gz; rm perl-Jdb-current.noarch.rpm; ln -s perl-Jdb-$(VERSION)-1.noarch.rpm perl-Jdb-current.noarch.rpm; rm perl-Jdb-current.src.rpm; ln -s perl-Jdb-$(VERSION)-1.src.rpm perl-Jdb-current.src.rpm; 
	@echo "to finish: git tag -sm $(VERSION)-release jdb-$(VERSION); cd $(WEBDIR); git commit -am \"release $(RPM_PREFIX)-$(VERSION)\""

END
close (MF);
